@@ -198,44 +198,34 @@ typedef struct {
 } FormatDetails;
 
 static const FormatName videoFormatNames[] = {
-    { NV_CTRL_GVO_VIDEO_FORMAT_480I_59_94_SMPTE259_NTSC, "720  x 480i    59.94  Hz  (SMPTE259) NTSC"},
-    { NV_CTRL_GVO_VIDEO_FORMAT_576I_50_00_SMPTE259_PAL,  "720  x 576i    50.00  Hz  (SMPTE259) PAL"},
-    { NV_CTRL_GVO_VIDEO_FORMAT_720P_23_98_SMPTE296,      "1280 x 720p    23.98  Hz  (SMPTE296)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_720P_24_00_SMPTE296,      "1280 x 720p    24.00  Hz  (SMPTE296)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_720P_25_00_SMPTE296,      "1280 x 720p    25.00  Hz  (SMPTE296)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_720P_29_97_SMPTE296,      "1280 x 720p    29.97  Hz  (SMPTE296)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_720P_30_00_SMPTE296,      "1280 x 720p    30.00  Hz  (SMPTE296)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_720P_50_00_SMPTE296,      "1280 x 720p    50.00  Hz  (SMPTE296)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_720P_59_94_SMPTE296,      "1280 x 720p    59.94  Hz  (SMPTE296)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_720P_60_00_SMPTE296,      "1280 x 720p    60.00  Hz  (SMPTE296)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1035I_59_94_SMPTE260,     "1920 x 1035i   59.94  Hz  (SMPTE260)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1035I_60_00_SMPTE260,     "1920 x 1035i   60.00  Hz  (SMPTE260)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_47_96_SMPTE274,     "1920 x 1080i   47.96  Hz  (SMPTE274)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_48_00_SMPTE274,     "1920 x 1080i   48.00  Hz  (SMPTE274)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_50_00_SMPTE295,     "1920 x 1080i   50.00  Hz  (SMPTE295)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_50_00_SMPTE274,     "1920 x 1080i   50.00  Hz  (SMPTE274)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_59_94_SMPTE274,     "1920 x 1080i   59.94  Hz  (SMPTE274)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_60_00_SMPTE274,     "1920 x 1080i   60.00  Hz  (SMPTE274)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080P_23_976_SMPTE274,    "1920 x 1080p   23.976 Hz  (SMPTE274)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080P_24_00_SMPTE274,     "1920 x 1080p   24.00  Hz  (SMPTE274)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080P_25_00_SMPTE274,     "1920 x 1080p   25.00  Hz  (SMPTE274)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080P_29_97_SMPTE274,     "1920 x 1080p   29.97  Hz  (SMPTE274)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080P_30_00_SMPTE274,     "1920 x 1080p   30.00  Hz  (SMPTE274)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_23_98_SMPTE274,   "1920 x 1080PsF 23.98  Hz  (SMPTE274)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_24_00_SMPTE274,   "1920 x 1080PsF 24.00  Hz  (SMPTE274)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_25_00_SMPTE274,   "1920 x 1080PsF 25.00  Hz  (SMPTE274)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_29_97_SMPTE274,   "1920 x 1080PsF 29.97  Hz  (SMPTE274)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_30_00_SMPTE274,   "1920 x 1080PsF 30.00  Hz  (SMPTE274)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_23_98_SMPTE372,     "2048 x 1080i   23.98  Hz  (SMPTE372)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_24_00_SMPTE372,     "2048 x 1080i   24.00  Hz  (SMPTE372)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_25_00_SMPTE372,     "2048 x 1080i   25.00  Hz  (SMPTE372)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_29_97_SMPTE372,     "2048 x 1080i   29.97  Hz  (SMPTE372)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_30_00_SMPTE372,     "2048 x 1080i   30.00  Hz  (SMPTE372)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080P_23_98_SMPTE372,     "2048 x 1080p   23.98  Hz  (SMPTE372)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080P_24_00_SMPTE372,     "2048 x 1080p   24.00  Hz  (SMPTE372)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080P_25_00_SMPTE372,     "2048 x 1080p   25.00  Hz  (SMPTE372)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080P_29_97_SMPTE372,     "2048 x 1080p   29.97  Hz  (SMPTE372)"    },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080P_30_00_SMPTE372,     "2048 x 1080p   30.00  Hz  (SMPTE372)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_480I_59_94_SMPTE259_NTSC, "480i    59.94  Hz  (SMPTE259) NTSC"},
+    { NV_CTRL_GVO_VIDEO_FORMAT_576I_50_00_SMPTE259_PAL,  "576i    50.00  Hz  (SMPTE259) PAL"},
+    { NV_CTRL_GVO_VIDEO_FORMAT_720P_23_98_SMPTE296,      "720p    23.98  Hz  (SMPTE296)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_720P_24_00_SMPTE296,      "720p    24.00  Hz  (SMPTE296)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_720P_25_00_SMPTE296,      "720p    25.00  Hz  (SMPTE296)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_720P_29_97_SMPTE296,      "720p    29.97  Hz  (SMPTE296)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_720P_30_00_SMPTE296,      "720p    30.00  Hz  (SMPTE296)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_720P_50_00_SMPTE296,      "720p    50.00  Hz  (SMPTE296)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_720P_59_94_SMPTE296,      "720p    59.94  Hz  (SMPTE296)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_720P_60_00_SMPTE296,      "720p    60.00  Hz  (SMPTE296)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_1035I_59_94_SMPTE260,     "1035i   59.94  Hz  (SMPTE260)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_1035I_60_00_SMPTE260,     "1035i   60.00  Hz  (SMPTE260)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_50_00_SMPTE295,     "1080i   50.00  Hz  (SMPTE295)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_50_00_SMPTE274,     "1080i   50.00  Hz  (SMPTE274)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_59_94_SMPTE274,     "1080i   59.94  Hz  (SMPTE274)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_60_00_SMPTE274,     "1080i   60.00  Hz  (SMPTE274)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_1080P_23_976_SMPTE274,    "1080p   23.976 Hz  (SMPTE274)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_1080P_24_00_SMPTE274,     "1080p   24.00  Hz  (SMPTE274)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_1080P_25_00_SMPTE274,     "1080p   25.00  Hz  (SMPTE274)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_1080P_29_97_SMPTE274,     "1080p   29.97  Hz  (SMPTE274)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_1080P_30_00_SMPTE274,     "1080p   30.00  Hz  (SMPTE274)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_47_96_SMPTE274,     "1080i   47.96  Hz  (SMPTE274)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_48_00_SMPTE274,     "1080i   48.00  Hz  (SMPTE274)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_25_00_SMPTE274,   "1080PsF 25.00  Hz  (SMPTE274)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_29_97_SMPTE274,   "1080PsF 29.97  Hz  (SMPTE274)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_30_00_SMPTE274,   "1080PsF 30.00  Hz  (SMPTE274)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_24_00_SMPTE274,   "1080PsF 24.00  Hz  (SMPTE274)"    },
+    { NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_23_98_SMPTE274,   "1080PsF 23.98  Hz  (SMPTE274)"    },
     { -1, NULL },
 };
 
@@ -253,8 +243,6 @@ static FormatDetails videoFormatDetails[] = {
     { NV_CTRL_GVO_VIDEO_FORMAT_720P_60_00_SMPTE296,      0, 0, 0 },
     { NV_CTRL_GVO_VIDEO_FORMAT_1035I_59_94_SMPTE260,     0, 0, 0 },
     { NV_CTRL_GVO_VIDEO_FORMAT_1035I_60_00_SMPTE260,     0, 0, 0 },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_47_96_SMPTE274,     0, 0, 0 },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_48_00_SMPTE274,     0, 0, 0 },
     { NV_CTRL_GVO_VIDEO_FORMAT_1080I_50_00_SMPTE295,     0, 0, 0 },
     { NV_CTRL_GVO_VIDEO_FORMAT_1080I_50_00_SMPTE274,     0, 0, 0 },
     { NV_CTRL_GVO_VIDEO_FORMAT_1080I_59_94_SMPTE274,     0, 0, 0 },
@@ -264,21 +252,13 @@ static FormatDetails videoFormatDetails[] = {
     { NV_CTRL_GVO_VIDEO_FORMAT_1080P_25_00_SMPTE274,     0, 0, 0 },
     { NV_CTRL_GVO_VIDEO_FORMAT_1080P_29_97_SMPTE274,     0, 0, 0 },
     { NV_CTRL_GVO_VIDEO_FORMAT_1080P_30_00_SMPTE274,     0, 0, 0 },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_23_98_SMPTE274,   0, 0, 0 },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_24_00_SMPTE274,   0, 0, 0 },
+    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_47_96_SMPTE274,     0, 0, 0 },
+    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_48_00_SMPTE274,     0, 0, 0 },
     { NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_25_00_SMPTE274,   0, 0, 0 },
     { NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_29_97_SMPTE274,   0, 0, 0 },
     { NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_30_00_SMPTE274,   0, 0, 0 },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_23_98_SMPTE372,     0, 0, 0 },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_24_00_SMPTE372,     0, 0, 0 },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_25_00_SMPTE372,     0, 0, 0 },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_29_97_SMPTE372,     0, 0, 0 },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080I_30_00_SMPTE372,     0, 0, 0 },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080P_23_98_SMPTE372,     0, 0, 0 },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080P_24_00_SMPTE372,     0, 0, 0 },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080P_25_00_SMPTE372,     0, 0, 0 },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080P_29_97_SMPTE372,     0, 0, 0 },
-    { NV_CTRL_GVO_VIDEO_FORMAT_1080P_30_00_SMPTE372,     0, 0, 0 },
+    { NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_24_00_SMPTE274,   0, 0, 0 },
+    { NV_CTRL_GVO_VIDEO_FORMAT_1080PSF_23_98_SMPTE274,   0, 0, 0 },
     { -1, -1, -1, -1 },
 };
 
@@ -286,7 +266,7 @@ static FormatDetails videoFormatDetails[] = {
 static const FormatName dataFormatNames[] = {
     { NV_CTRL_GVO_DATA_FORMAT_R8G8B8_TO_YCRCB444, "RGB -> YCrCb (4:4:4)" },
     { NV_CTRL_GVO_DATA_FORMAT_R8G8B8_TO_YCRCB422, "RGB -> YCrCb (4:2:2)" },
-    { NV_CTRL_GVO_DATA_FORMAT_X8X8X8_444_PASSTHRU,"RGB (4:4:4)" },
+    { NV_CTRL_GVO_DATA_FORMAT_R8G8B8_TO_RGB444,   "RGB (4:4:4)" },
     { -1, NULL },
 };
 
@@ -336,7 +316,7 @@ GtkWidget* ctk_gvo_new(NvCtrlAttributeHandle *handle,
     CtkGvo *ctk_gvo;
     GtkWidget *hbox, *alignment, *button, *label;
     ReturnStatus ret;
-    gchar scratch[64], *firmware, *string;
+    gchar scratch[64], *firmware;
     gint val, i, width, height, n;
     
     GtkWidget *frame, *table, *menu;
@@ -398,32 +378,15 @@ GtkWidget* ctk_gvo_new(NvCtrlAttributeHandle *handle,
     gtk_container_set_border_width(GTK_CONTAINER(table), 5);
     gtk_container_add(GTK_CONTAINER(frame), table);
     
-    /* GVO_FIRMWARE_VERSION */
+    /* NV_CTRL_GVO_FIRMWARE_VERSION */
+
+    ret = NvCtrlGetAttribute(handle, NV_CTRL_GVO_FIRMWARE_VERSION, &val);
     
-    string = NULL;
-    
-    ret = NvCtrlGetStringAttribute(handle,
-                                   NV_CTRL_STRING_GVO_FIRMWARE_VERSION, 
-                                   &string);
-    
-    if ((ret == NvCtrlSuccess) && (string)) {
-        firmware = strdup(string);
+    if (ret == NvCtrlSuccess) {
+        snprintf(scratch, 64, "1.%02d", val);
+        firmware = strdup(scratch);
     } else {
-        
-        /*
-         * NV_CTRL_STRING_GVO_FIRMWARE_VERSION was added later, so
-         * older X servers may not know about it; fallback to
-         * NV_CTRL_GVO_FIRMWARE_VERSION
-         */
-        
-        ret = NvCtrlGetAttribute(handle, NV_CTRL_GVO_FIRMWARE_VERSION, &val);
-        
-        if (ret == NvCtrlSuccess) {
-            snprintf(scratch, 64, "1.%02d", val);
-            firmware = strdup(scratch);
-        } else {
-            firmware = strdup("???");
-        }
+        firmware = strdup("???");
     }
     
     add_table_row(table, 0, 0, "Firmware Version:", firmware);
@@ -1283,11 +1246,7 @@ static void output_video_format_changed(CtkDropDownMenu *menu,
     
     value = ctk_drop_down_menu_get_current_value(menu);
     
-    if (((value < 32) &&
-         !(ctk_gvo->valid_output_video_format_mask[0] & (1 << value))) ||
-        ((value >= 32) &&
-         !(ctk_gvo->valid_output_video_format_mask[1] & (1 << (value - 32))))){
-        
+    if (!(ctk_gvo->valid_putput_video_format_mask & (1 << value))) {
         ctk_config_statusbar_message(ctk_gvo->ctk_config, "Invalid "
                                      "Output Video Format: %s; ignoring.",
                                      get_video_format_name(value));
@@ -1460,7 +1419,7 @@ static void update_output_video_format_menu(CtkGvo *ctk_gvo)
 {
     ReturnStatus ret;
     NVCTRLAttributeValidValuesRec valid;
-    gint bitmask, bitmask2, i, refresh_rate;
+    gint bitmask, i, refresh_rate;
     gboolean sensitive, current_not_available = FALSE;
 
     /* retrieve the currently available values */
@@ -1477,20 +1436,6 @@ static void update_output_video_format_menu(CtkGvo *ctk_gvo)
         bitmask = valid.u.bits.ints;
     }
     
-    /* retrieve additional available values */
-
-    ret = NvCtrlGetValidAttributeValues(ctk_gvo->handle,
-                                        NV_CTRL_GVO_OUTPUT_VIDEO_FORMAT2,
-                                        &valid);
-
-    /* if we failed to get the available values; assume none are valid */
-    
-    if ((ret != NvCtrlSuccess) || (valid.type != ATTRIBUTE_TYPE_INT_BITS)) {
-        bitmask2 = 0;
-    } else {
-        bitmask2 = valid.u.bits.ints;
-    }
-
     /* 
      * if the SyncMode is genlock or framelock, trim the bitmask
      * accordingly: if GENLOCK, then the only bit allowed is the bit
@@ -1501,14 +1446,7 @@ static void update_output_video_format_menu(CtkGvo *ctk_gvo)
     
     if ((ctk_gvo->sync_mode == NV_CTRL_GVO_SYNC_MODE_GENLOCK) &&
         (ctk_gvo->input_video_format != NV_CTRL_GVO_VIDEO_FORMAT_NONE)) {
-
-        if (ctk_gvo->input_video_format < 32) {
-            bitmask &= (1 << ctk_gvo->input_video_format);
-            bitmask2 = 0;
-        } else {
-            bitmask = 0;
-            bitmask2 &= (1 << (ctk_gvo->input_video_format - 32));
-        }
+        bitmask &= (1 << ctk_gvo->input_video_format);
     }
     
     if ((ctk_gvo->sync_mode == NV_CTRL_GVO_SYNC_MODE_FRAMELOCK) &&
@@ -1525,12 +1463,7 @@ static void update_output_video_format_menu(CtkGvo *ctk_gvo)
         
         for (i = 0; videoFormatDetails[i].format != -1; i++) {
             if (videoFormatDetails[i].rate != refresh_rate) {
-                
-                if (videoFormatDetails[i].format < 32) {
-                    bitmask &= ~(1 << videoFormatDetails[i].format);
-                } else {
-                    bitmask2 &= ~(1 << (videoFormatDetails[i].format - 32));
-                }
+                bitmask &= ~(1 << videoFormatDetails[i].format);
             }
         }
     }
@@ -1541,10 +1474,7 @@ static void update_output_video_format_menu(CtkGvo *ctk_gvo)
      */
 
     for (i = 0; videoFormatNames[i].name; i++) {
-        if (((videoFormatNames[i].format < 32) &&
-             ((1 << videoFormatNames[i].format) & bitmask)) ||
-            ((videoFormatNames[i].format >= 32) &&
-             (((1 << (videoFormatNames[i].format - 32)) & bitmask2)))) {
+        if ((1 << videoFormatNames[i].format) & bitmask) {
             sensitive = TRUE;
         } else {
             sensitive = FALSE;
@@ -1569,10 +1499,7 @@ static void update_output_video_format_menu(CtkGvo *ctk_gvo)
     
     if (current_not_available && bitmask) {
         for (i = 0; videoFormatNames[i].name; i++) {
-            if (((videoFormatNames[i].format < 32) &&
-                 ((1 << videoFormatNames[i].format) & bitmask)) ||
-                ((videoFormatNames[i].format >= 32) &&
-                 ((1 << (videoFormatNames[i].format - 32)) & bitmask2))) {
+            if ((1 << videoFormatNames[i].format) & bitmask) {
                 
                 NvCtrlSetAttribute(ctk_gvo->handle,
                                    NV_CTRL_GVO_OUTPUT_VIDEO_FORMAT,
@@ -1593,8 +1520,7 @@ static void update_output_video_format_menu(CtkGvo *ctk_gvo)
      * cache the bitmask
      */
 
-    ctk_gvo->valid_output_video_format_mask[0] = bitmask;
-    ctk_gvo->valid_output_video_format_mask[1] = bitmask2;
+    ctk_gvo->valid_putput_video_format_mask = bitmask;
     
 } /* update_output_video_format_menu() */
 
