@@ -47,28 +47,6 @@ Bool XNVCTRLIsNvScreen (
 );
 
 
-/*
- *  XNVCTRLQueryTargetCount -
- *
- *  Returns True if the target type exists.  Returns False otherwise.
- *  If XNVCTRLQueryTargetCount returns True, value will contain the
- *  count of existing targets on the server of the specified target
- *  type.
- *
- *  Please see "Attribute Targets" in NVCtrl.h for the list of valid
- *  target types.
- *
- *  Possible errors:
- *     BadValue - The target doesn't exist.
- */
-
-Bool XNVCTRLQueryTargetCount (
-    Display *dpy,
-    int target_type,
-    int *value
-);
-
-
 /*
  *  XNVCTRLSetAttribute -
  *
@@ -78,10 +56,6 @@ Bool XNVCTRLQueryTargetCount (
  *  Not all attributes require the display_mask parameter; see
  *  NVCtrl.h for details.
  *
- *  Calling this function is equivalent to calling XNVCTRLSetTargetAttribute()
- *  with the target_type set to NV_CTRL_TARGET_TYPE_X_SCREEN and
- *  target_id set to 'screen'.
- *
  *  Possible errors:
  *     BadValue - The screen or attribute doesn't exist.
  *     BadMatch - The NVIDIA driver is not present on that screen.
@@ -96,30 +70,6 @@ void XNVCTRLSetAttribute (
 );
 
 
-/*
- *  XNVCTRLSetTargetAttribute -
- *
- *  Sets the attribute to the given value.  The attributes and their
- *  possible values are listed in NVCtrl.h.
- *
- *  Not all attributes require the display_mask parameter; see
- *  NVCtrl.h for details.
- *
- *  Possible errors:
- *     BadValue - The target or attribute doesn't exist.
- *     BadMatch - The NVIDIA driver is not present on that target.
- */
-
-void XNVCTRLSetTargetAttribute (
-    Display *dpy,
-    int target_type,
-    int target_id,
-    unsigned int display_mask,
-    unsigned int attribute,
-    int value
-);
-
-
 /*
  *  XNVCTRLSetAttributeAndGetStatus -
  *
@@ -148,10 +98,6 @@ Bool XNVCTRLSetAttributeAndGetStatus (
  *  Not all attributes require the display_mask parameter; see
  *  NVCtrl.h for details.
  *
- *  Calling this function is equivalent to calling
- *  XNVCTRLQueryTargetAttribute() with the target_type set to
- *  NV_CTRL_TARGET_TYPE_X_SCREEN and target_id set to 'screen'.
- *
  *  Possible errors:
  *     BadValue - The screen doesn't exist.
  *     BadMatch - The NVIDIA driver is not present on that screen.
@@ -166,31 +112,6 @@ Bool XNVCTRLQueryAttribute (
 );
 
 
-/*
- * XNVCTRLQueryTargetAttribute -
- *
- *  Returns True if the attribute exists.  Returns False otherwise.
- *  If XNVCTRLQueryTargetAttribute returns True, value will contain the
- *  value of the specified attribute.
- *
- *  Not all attributes require the display_mask parameter; see
- *  NVCtrl.h for details.
- *
- *  Possible errors:
- *     BadValue - The target doesn't exist.
- *     BadMatch - The NVIDIA driver does not control the target.
- */
-
-Bool XNVCTRLQueryTargetAttribute (
-    Display *dpy,
-    int target_Type,
-    int target_id,
-    unsigned int display_mask,
-    unsigned int attribute,
-    int *value
-);
-
-
 /*
  *  XNVCTRLQueryStringAttribute -
  *
@@ -199,10 +120,6 @@ Bool XNVCTRLQueryTargetAttribute (
  *  allocated string containing the string attribute requested.  It is
  *  the caller's responsibility to free the string when done.
  *
- *  Calling this function is equivalent to calling
- *  XNVCTRLQueryTargetStringAttribute() with the target_type set to
- *  NV_CTRL_TARGET_TYPE_X_SCREEN and target_id set to 'screen'.
- *
  *  Possible errors:
  *     BadValue - The screen doesn't exist.
  *     BadMatch - The NVIDIA driver is not present on that screen.
@@ -217,31 +134,6 @@ Bool XNVCTRLQueryStringAttribute (
     char **ptr
 );
 
-
-/*
- *  XNVCTRLQueryTargetStringAttribute -
- *
- *  Returns True if the attribute exists.  Returns False otherwise.
- *  If XNVCTRLQueryTargetStringAttribute returns True, *ptr will point
- *  to an allocated string containing the string attribute requested.
- *  It is the caller's responsibility to free the string when done.
- *
- *  Possible errors:
- *     BadValue - The target doesn't exist.
- *     BadMatch - The NVIDIA driver does not control the target.
- *     BadAlloc - Insufficient resources to fulfill the request.
- */
-
-Bool XNVCTRLQueryTargetStringAttribute (
-    Display *dpy,
-    int target_type,
-    int target_id,
-    unsigned int display_mask,
-    unsigned int attribute,
-    char **ptr
-);
-
-
 /*
  *  XNVCTRLSetStringAttribute -
  *
@@ -261,7 +153,6 @@ Bool XNVCTRLSetStringAttribute (
     char *ptr
 );
 
-
 /*
  * XNVCTRLQueryValidAttributeValues -
  *
@@ -269,10 +160,6 @@ Bool XNVCTRLSetStringAttribute (
  * XNVCTRLQueryValidAttributeValues returns True, values will indicate
  * the valid values for the specified attribute; see the description
  * of NVCTRLAttributeValidValues in NVCtrl.h.
- *
- *  Calling this function is equivalent to calling
- *  XNVCTRLQueryValidTargetAttributeValues() with the target_type set to
- *  NV_CTRL_TARGET_TYPE_X_SCREEN and target_id set to 'screen'.
  */
 
 Bool XNVCTRLQueryValidAttributeValues (
@@ -284,69 +171,11 @@ Bool XNVCTRLQueryValidAttributeValues (
 );
 
 
-
-/*
- * XNVCTRLQueryValidTargetAttributeValues -
- *
- * Returns True if the attribute exists.  Returns False otherwise.  If
- * XNVCTRLQueryValidTargetAttributeValues returns True, values will indicate
- * the valid values for the specified attribute.
- */
-
-Bool XNVCTRLQueryValidTargetAttributeValues (
-    Display *dpy,
-    int target_type,
-    int target_id,
-    unsigned int display_mask,
-    unsigned int attribute,                                 
-    NVCTRLAttributeValidValuesRec *values
-);
-
-
 /*
  *  XNVCTRLSetGvoColorConversion -
  *
- *  Sets the color conversion matrix, offset, and scale that should be
- *  used for GVO (Graphic to Video Out).
- *
- *  The Color Space Conversion data is ordered like this:
- *
- *   colorMatrix[0][0] // r.Y
- *   colorMatrix[0][1] // g.Y
- *   colorMatrix[0][2] // b.Y
- *
- *   colorMatrix[1][0] // r.Cr
- *   colorMatrix[1][1] // g.Cr
- *   colorMatrix[1][2] // b.Cr
- *
- *   colorMatrix[2][0] // r.Cb
- *   colorMatrix[2][1] // g.Cb
- *   colorMatrix[2][2] // b.Cb
- *
- *   colorOffset[0]    // Y
- *   colorOffset[1]    // Cr
- *   colorOffset[2]    // Cb
- *
- *   colorScale[0]     // Y
- *   colorScale[1]     // Cr
- *   colorScale[2]     // Cb
- *
- *  where the data is used according to the following formulae:
- *
- *   Y  =  colorOffset[0] + colorScale[0] *
- *           (R * colorMatrix[0][0] +
- *            G * colorMatrix[0][1] +
- *            B * colorMatrix[0][2]);
- *
- *   Cr =  colorOffset[1] + colorScale[1] *
- *           (R * colorMatrix[1][0] +
- *            G * colorMatrix[1][1] +
- *            B * colorMatrix[1][2]);
- *
- *   Cb =  colorOffset[2] + colorScale[2] *
- *           (R * colorMatrix[2][0] +
- *            G * colorMatrix[2][1] +
- *            B * colorMatrix[2][2]);
+ *  Sets the color conversion matrix and color offset
+ *  that should be used for GVO (Graphic to Video Out).
  *
  *  Possible errors:
  *     BadMatch - The NVIDIA driver is not present on that screen.
@@ -357,21 +186,16 @@ void XNVCTRLSetGvoColorConversion (
     Display *dpy,
     int screen,
     float colorMatrix[3][3],
-    float colorOffset[3],
-    float colorScale[3]
+    float colorOffset[3]
 );
 
 
-
 /*
  *  XNVCTRLQueryGvoColorConversion -
  *
  *  Retrieves the color conversion matrix and color offset
  *  that are currently being used for GVO (Graphic to Video Out).
  *
- *  The values are ordered within the arrays according to the comments
- *  for XNVCTRLSetGvoColorConversion().
- *
  *  Possible errors:
  *     BadMatch - The NVIDIA driver is not present on that screen.
  *     BadImplementation - GVO is not available on that screen.
@@ -381,11 +205,9 @@ Bool XNVCTRLQueryGvoColorConversion (
     Display *dpy,
     int screen,
     float colorMatrix[3][3],
-    float colorOffset[3],
-    float colorScale[3]
+    float colorOffset[3]
 );
 
-
 /* SPECIAL HANDLING OF VCP CODES 
  *
  * XNVCTRLQueryDDCCILutSize
@@ -605,68 +427,12 @@ Bool XNVCTRLQueryDDCCITimingReport (
 );
 
 
-/*
- *  XNVCTRLQueryBinaryData -
- *
- *  Returns True if the attribute exists.  Returns False otherwise.
- *  If XNVCTRLQueryBinaryData returns True, *ptr will point to an
- *  allocated block of memory containing the binary data attribute
- *  requested.  It is the caller's responsibility to free the data
- *  when done.  len will list the length of the binary data.
- *
- *  Calling this function is equivalent to calling
- *  XNVCTRLQueryTargetBinaryData() with the target_type set to
- *  NV_CTRL_TARGET_TYPE_X_SCREEN and target_id set to 'screen'.
- *
- *  Possible errors:
- *     BadValue - The screen doesn't exist.
- *     BadMatch - The NVIDIA driver is not present on that screen.
- *     BadAlloc - Insufficient resources to fulfill the request.
- */
-
-Bool XNVCTRLQueryBinaryData (
-    Display *dpy,
-    int screen,
-    unsigned int display_mask,
-    unsigned int attribute,
-    unsigned char **ptr,
-    int *len
-);
-
-
-/*
- * XNVCTRLQueryTargetBinaryData -
- *
- *  Returns True if the attribute exists.  Returns False otherwise.
- *  If XNVCTRLQueryTargetBinaryData returns True, *ptr will point to an
- *  allocated block of memory containing the binary data attribute
- *  requested.  It is the caller's responsibility to free the data
- *  when done.  len will list the length of the binary data.
- *
- *  Possible errors:
- *     BadValue - The target doesn't exist.
- *     BadMatch - The NVIDIA driver does not control the target.
- *     BadAlloc - Insufficient resources to fulfill the request.
- */
-
-Bool XNVCTRLQueryTargetBinaryData (
-    Display *dpy,
-    int target_type,
-    int target_id,
-    unsigned int display_mask,
-    unsigned int attribute,
-    unsigned char **ptr,
-    int *len
-);
-
-
 /*
  * XNVCtrlSelectNotify -
  *
  * This enables/disables receiving of NV-CONTROL events.  The type
- * specifies the type of event to enable (currently, the only
- * type that can be requested per-screen with XNVCtrlSelectNotify()
- * is ATTRIBUTE_CHANGED_EVENT); onoff controls whether receiving this
+ * specifies the type of event to enable (currently, the only type is
+ * ATTRIBUTE_CHANGED_EVENT); onoff controls whether receiving this
  * type of event should be enabled (True) or disabled (False).
  *
  * Returns True if successful, or False if the screen is not
@@ -681,28 +447,6 @@ Bool XNVCtrlSelectNotify (
 );
 
 
-/*
- * XNVCtrlSelectTargetNotify -
- *
- * This enables/disables receiving of NV-CONTROL events that happen on
- * the specified target.  The notify_type specifies the type of event to
- * enable (currently, the only type that can be requested per-target with
- * XNVCtrlSelectTargetNotify() is TARGET_ATTRIBUTE_CHANGED_EVENT); onoff
- * controls whether receiving this type of event should be enabled (True)
- * or disabled (False).
- *
- * Returns True if successful, or False if the target is not
- * controlled by the NVIDIA driver.
- */
-
-Bool XNVCtrlSelectTargetNotify (
-    Display *dpy,
-    int target_type,
-    int target_id,
-    int notify_type,
-    Bool onoff
-);
-
 
 /*
  * XNVCtrlEvent structure
@@ -727,28 +471,4 @@ typedef union {
 } XNVCtrlEvent;
 
 
-/*
- * XNVCtrlEventTarget structure
- */
-
-typedef struct {
-    int type;
-    unsigned long serial;
-    Bool send_event;  /* always FALSE, we don't allow send_events */
-    Display *display;
-    Time time;
-    int target_type;
-    int target_id;
-    unsigned int display_mask;
-    unsigned int attribute;
-    int value;
-} XNVCtrlAttributeChangedEventTarget;
-
-typedef union {
-    int type;
-    XNVCtrlAttributeChangedEventTarget attribute_changed;
-    long pad[24];
-} XNVCtrlEventTarget;
-
-
 #endif /* __NVCTRLLIB_H */
